% --- Source file: checkUsage.Rd ---
\name{checkUsage}
\title{Check R Code for Possible Problems}
\usage{
checkUsage(fun, name = "<anonymous>", report = cat, all = FALSE, 
           suppressLocal = FALSE, suppressParamAssigns = !all,
           suppressParamUnused = !all, suppressFundefMismatch = FALSE,
           suppressLocalUnused = FALSE, suppressNoLocalFun = !all,
           skipWith = FALSE, suppressUndefined = dfltSuppressUndefined) 
checkUsageEnv(env, ...) 
checkUsagePackage(pack, ...) 
}
\alias{checkUsage}
\alias{checkUsageEnv}
\alias{checkUsagePackage}
\arguments{
  \item{fun}{closure.}
  \item{name}{character; name of closure.}
  \item{env}{environment containing closures to check.}
  \item{pack}{character naming package to check.}
  \item{\dots}{options to be passed to \code{checkUsage}.}
  \item{report}{function to use to report possible problems.}
  \item{all}{logical; report all possible problems if TRUE.}
  \item{suppressLocal}{suppress all local variable warnings.}
  \item{suppressParamAssigns}{suppress warnings about assignments to formal
                              parameters.}
  \item{suppressParamUnused}{suppress warnings about unused formal
                             parameters.}
  \item{suppressFundefMismatch}{suppress warnings about multiple local
                                function definitions with different formal
                                argument lists}
  \item{suppressLocalUnused}{suppress warnings about unused local variables}
  \item{suppressNoLocalFun}{suppress warnings about using local variables
                            as functions with no apparent local function
                            definition}
  \item{skipWith}{logical; if true, do no examine code portion of
                  \code{with} expressions.}
  \item{suppressUndefined}{suppress warnings about undefined global
                          functions and variables.}
}
\description{
  Check R code for possible problems.
}
\details{
  \code{checkUsage} checks a single R closure.  Options control which
  possible problems to report.  The default settings are moderately
  verbose.  A first pass might use \code{suppressLocal=TRUE} to
  suppress all information related to local variable usage.
  The \code{suppressXYZ} values can either be scalar logicals or
  character vectors; then they are character vectors they only
  suppress problem reports for the variables with names in the vector.

  \code{checkUsageEnv} and \code{checkUsagePackage} are convenience
  functions that apply \code{checkUsage} to all closures in an
  environment or a package.  \code{checkUsagePackage} requires that the
  package be loaded.  If the package has a name space then the internal
  name space frame is checked.
}
\author{Luke Tierney}

\examples{
checkUsage(checkUsage)
checkUsagePackage("codetools",all=TRUE)
\dontrun{checkUsagePackage("base",suppressLocal=TRUE)}
}
\keyword{programming}
\eof
% --- Source file: codetools.Rd ---
\name{codetools}
\alias{codetools}
\title{Low Level Code Analysis Tools for R}
\usage{
collectLocals(e, collect) 
collectUsage(fun, name = "<anonymous>", ...) 
constantFold(e, env = NULL, fail = NULL) 
findFuncLocals(formals, body) 
findLocals(e, envir = .BaseEnv) 
findLocalsList(elist, envir = .BaseEnv)
flattenAssignment(e) 
getAssignedVar(e) 
isConstantValue(v, w) 
makeCodeWalker(..., handler, call, leaf) 
makeLocalsCollector(..., leaf, handler, isLocal, exit, collect) 
makeUsageCollector(fun, ..., name, enterLocal, enterGlobal, enterInternal,
                   startCollectLocals, finishCollectLocals, warn,
                   signal)
walkCode(e, w = makeCodeWalker()) 
}
\alias{collectLocals}
\alias{collectUsage}
\alias{constantFold}
\alias{findFuncLocals}
\alias{findLocals}
\alias{findLocalsList}
\alias{flattenAssignment}
\alias{getAssignedVar}
\alias{isConstantValue}
\alias{makeCodeWalker}
\alias{makeConstantFolder}
\alias{makeLocalsCollector}
\alias{makeUsageCollector}
\alias{walkCode}
\arguments{
  \item{e}{R expression.}
  \item{elist}{list of R expressions.}
  \item{v}{R object.}
  \item{fun}{closure.}
  \item{formals}{formal arguments of a closure.}
  \item{body}{body of a closure.}
  \item{name}{character.}
  \item{env}{character.}
  \item{envir}{environment.}
  \item{w}{code walker.}
  \item{\dots}{extra elements for code walker.}
  \item{collect}{function.}
  \item{fail}{function.}
  \item{handler}{function.}
  \item{call}{function.}
  \item{leaf}{function.}
  \item{isLocal}{function.}
  \item{exit}{function.}
  \item{enterLocal}{function.}
  \item{enterGlobal}{function.}
  \item{enterInternal}{function.}
  \item{startCollectLocals}{function.}
  \item{finishCollectLocals}{function.}
  \item{warn}{function.}
  \item{signal}{function.}
}
\description{
  These functions provide some tools for analysing R code.  Mainly
  indented to support the other tools in this package and byte code
  compilation.
}
\author{Luke Tierney}
\keyword{programming}
\eof
% --- Source file: findGlobals.Rd ---
\name{findGlobals}
\title{Find Global Functions and Variables Used by a Closure}
\usage{
findGlobals(fun, merge = TRUE) 
}
\alias{findGlobals}
\arguments{
  \item{fun}{closure.}
  \item{merge}{logical}
}
\value{
  Character vector if \code{merge} is true; otherwise, a list with
  \code{functions} and \code{variables} components.
}
\description{
  Finds global functions and variables used by a closure.
}
\details{
  The result is an approximation. R semantics only allow variables
  that might be local to be identified (and event that assumes no use
  of \code{assign} and \code{rm}).
}
\author{Luke Tierney}

\examples{
findGlobals(findGlobals)
findGlobals(findGlobals, merge = FALSE)
}
\keyword{programming}
\eof
% --- Source file: showTree.Rd ---
\name{showTree}
\title{Print Lisp-Style Representation of R Expression}
\usage{
showTree(e, write = cat)
}
\alias{showTree}
\arguments{
  \item{e}{R expression.}
  \item{write}{function of one argument to write the result.}
}
\description{
  Prints a Lisp-style representation of R expression.  This can be
  useful for understanding how some things are parsed.
}
\author{Luke Tierney}

\examples{
showTree(quote(-3))
showTree(quote("x"<-1))
showTree(quote("f"(x)))
}
\keyword{programming}
\eof
